
# known

**known** is a collection of reusable python code. Use pip to install **known**

```bash
   pip install known
```
or

```bash
   python -m pip install known
```
The package is frequently updated by adding new functionality, make sure to have the latest version.
[Visit PyPI package homepage](https://pypi.org/project/known)


The github version is always upto-date. To install from github, use the following:
```bash
git clone https://github.com/auto-notify-ps/known.git
cd known
python -m pip install .
```
